package betterquesting.client.gui2.editors;

import betterquesting.api.client.gui.misc.INeedsRefresh;
import betterquesting.api.client.gui.misc.IVolatileScreen;
import betterquesting.api.properties.NativeProps;
import betterquesting.api.questing.IQuest;
import betterquesting.api.questing.IQuestLine;
import betterquesting.api.questing.IQuestLineEntry;
import betterquesting.api2.client.gui.GuiScreenCanvas;
import betterquesting.api2.client.gui.controls.PanelButton;
import betterquesting.api2.client.gui.controls.PanelButtonStorage;
import betterquesting.api2.client.gui.controls.PanelTextField;
import betterquesting.api2.client.gui.controls.filters.FieldFilterString;
import betterquesting.api2.client.gui.events.IPEventListener;
import betterquesting.api2.client.gui.events.PEventBroadcaster;
import betterquesting.api2.client.gui.events.PanelEvent;
import betterquesting.api2.client.gui.events.types.PEventButton;
import betterquesting.api2.client.gui.misc.GuiAlign;
import betterquesting.api2.client.gui.misc.GuiPadding;
import betterquesting.api2.client.gui.misc.GuiRectangle;
import betterquesting.api2.client.gui.misc.GuiTransform;
import betterquesting.api2.client.gui.panels.CanvasEmpty;
import betterquesting.api2.client.gui.panels.CanvasTextured;
import betterquesting.api2.client.gui.panels.bars.PanelVScrollBar;
import betterquesting.api2.client.gui.panels.content.PanelLine;
import betterquesting.api2.client.gui.panels.content.PanelTextBox;
import betterquesting.api2.client.gui.panels.lists.CanvasQuestDatabase;
import betterquesting.api2.client.gui.panels.lists.CanvasScrolling;
import betterquesting.api2.client.gui.themes.presets.PresetColor;
import betterquesting.api2.client.gui.themes.presets.PresetIcon;
import betterquesting.api2.client.gui.themes.presets.PresetLine;
import betterquesting.api2.client.gui.themes.presets.PresetTexture;
import betterquesting.api2.storage.DBEntry;
import betterquesting.api2.utils.QuestTranslation;
import betterquesting.client.gui2.GuiQuest;
import betterquesting.network.handlers.NetChapterEdit;
import betterquesting.network.handlers.NetQuestEdit;
import betterquesting.questing.QuestDatabase;
import betterquesting.questing.QuestLineDatabase;
import betterquesting.questing.QuestLineEntry;
import java.util.List;
import javax.annotation.Nullable;
import net.minecraft.client.gui.GuiScreen;
import net.minecraft.nbt.NBTTagCompound;
import net.minecraft.nbt.NBTTagList;
import org.lwjgl.input.Keyboard;

/* loaded from: betterquesting_client_gui2_editors.jar:betterquesting/client/gui2/editors/GuiQuestLineAddRemove.class */
public class GuiQuestLineAddRemove extends GuiScreenCanvas implements IPEventListener, IVolatileScreen, INeedsRefresh {

    @Nullable
    private IQuestLine questLine;
    private final int lineID;
    private CanvasQuestDatabase canvasDB;
    private CanvasScrolling canvasQL;

    public GuiQuestLineAddRemove(GuiScreen parent, @Nullable IQuestLine questLine) {
        super(parent);
        this.questLine = questLine;
        this.lineID = QuestLineDatabase.INSTANCE.getID(questLine);
    }

    public void refreshGui() {
        this.questLine = this.lineID < 0 ? null : (IQuestLine) QuestLineDatabase.INSTANCE.getValue(this.lineID);
        this.canvasDB.refreshSearch();
        if (this.questLine != null) {
            refreshQuestList();
        }
    }

    public void initPanel() {
        super.initPanel();
        PEventBroadcaster.INSTANCE.register(this, PEventButton.class);
        Keyboard.enableRepeatEvents(true);
        CanvasTextured cvBackground = new CanvasTextured(new GuiTransform(GuiAlign.FULL_BOX, new GuiPadding(0, 0, 0, 0), 0), PresetTexture.PANEL_MAIN.getTexture());
        addPanel(cvBackground);
        GuiTransform guiTransform = new GuiTransform(GuiAlign.TOP_EDGE, new GuiPadding(0, 16, 0, -32), 0);
        Object[] objArr = new Object[1];
        objArr[0] = this.questLine == null ? "" : QuestTranslation.translate(this.questLine.getUnlocalisedName(), new Object[0]);
        PanelTextBox panTxt = new PanelTextBox(guiTransform, QuestTranslation.translate("betterquesting.title.edit_line2", objArr)).setAlignment(1);
        panTxt.setColor(PresetColor.TEXT_HEADER.getColor());
        cvBackground.addPanel(panTxt);
        cvBackground.addPanel(new PanelButton(new GuiTransform(GuiAlign.BOTTOM_CENTER, -100, -16, 200, 16, 0), 0, QuestTranslation.translate("gui.back", new Object[0])));
        CanvasEmpty cvLeft = new CanvasEmpty(new GuiTransform(GuiAlign.HALF_LEFT, new GuiPadding(16, 32, 8, 24), 8));
        cvBackground.addPanel(cvLeft);
        if (this.questLine != null) {
            PanelTextBox txtQuest = new PanelTextBox(new GuiTransform(GuiAlign.TOP_EDGE, new GuiPadding(0, 0, 0, -16), 0), QuestTranslation.translate(this.questLine.getUnlocalisedName(), new Object[0])).setAlignment(1).setColor(PresetColor.TEXT_MAIN.getColor());
            cvLeft.addPanel(txtQuest);
        }
        this.canvasQL = new CanvasScrolling(new GuiTransform(GuiAlign.FULL_BOX, new GuiPadding(0, 16, 8, 0), 0));
        cvLeft.addPanel(this.canvasQL);
        PanelVScrollBar scReq = new PanelVScrollBar(new GuiTransform(GuiAlign.RIGHT_EDGE, new GuiPadding(-8, 16, 0, 0), 0));
        cvLeft.addPanel(scReq);
        this.canvasQL.setScrollDriverY(scReq);
        CanvasEmpty cvRight = new CanvasEmpty(new GuiTransform(GuiAlign.HALF_RIGHT, new GuiPadding(8, 32, 16, 24), 0));
        cvBackground.addPanel(cvRight);
        PanelTextBox txtDb = new PanelTextBox(new GuiTransform(GuiAlign.TOP_EDGE, new GuiPadding(0, 0, 0, -16), 0), QuestTranslation.translate("betterquesting.gui.database", new Object[0])).setAlignment(1).setColor(PresetColor.TEXT_MAIN.getColor());
        cvRight.addPanel(txtDb);
        PanelTextField<String> searchBox = new PanelTextField<>(new GuiTransform(GuiAlign.TOP_EDGE, new GuiPadding(0, 16, 8, -32), 0), "", FieldFilterString.INSTANCE);
        searchBox.setWatermark("Search...");
        cvRight.addPanel(searchBox);
        this.canvasDB = new CanvasQuestDatabase(new GuiTransform(GuiAlign.FULL_BOX, new GuiPadding(0, 32, 8, 24), 0)) { // from class: betterquesting.client.gui2.editors.GuiQuestLineAddRemove.1
            /* JADX INFO: Access modifiers changed from: protected */
            public boolean addResult(DBEntry<IQuest> entry, int index, int width) {
                PanelButtonStorage<DBEntry<IQuest>> btnAdd = new PanelButtonStorage<>(new GuiRectangle(0, index * 16, 16, 16, 0), 2, "", entry);
                btnAdd.setIcon(PresetIcon.ICON_POSITIVE.getTexture());
                btnAdd.setActive(GuiQuestLineAddRemove.this.questLine != null && GuiQuestLineAddRemove.this.questLine.getValue(entry.getID()) == null);
                addPanel(btnAdd);
                PanelButtonStorage<DBEntry<IQuest>> btnEdit = new PanelButtonStorage<>(new GuiRectangle(16, index * 16, width - 32, 16, 0), 1, QuestTranslation.translate((String) ((IQuest) entry.getValue()).getProperty(NativeProps.NAME), new Object[0]), entry);
                addPanel(btnEdit);
                PanelButtonStorage<DBEntry<IQuest>> btnDel = new PanelButtonStorage<>(new GuiRectangle(width - 16, index * 16, 16, 16, 0), 4, "", entry);
                btnDel.setIcon(PresetIcon.ICON_TRASH.getTexture());
                addPanel(btnDel);
                return true;
            }
        };
        cvRight.addPanel(this.canvasDB);
        CanvasQuestDatabase canvasQuestDatabase = this.canvasDB;
        canvasQuestDatabase.getClass();
        searchBox.setCallback(canvasQuestDatabase::setSearchFilter);
        PanelVScrollBar scDb = new PanelVScrollBar(new GuiTransform(GuiAlign.RIGHT_EDGE, new GuiPadding(-8, 32, 0, 24), 0));
        cvRight.addPanel(scDb);
        this.canvasDB.setScrollDriverY(scDb);
        PanelButton btnNew = new PanelButton(new GuiTransform(GuiAlign.BOTTOM_EDGE, new GuiPadding(0, -16, 0, 0), 0), 5, QuestTranslation.translate("betterquesting.btn.new", new Object[0]));
        cvRight.addPanel(btnNew);
        GuiTransform guiTransform2 = new GuiTransform(GuiAlign.TOP_CENTER, 0, 32, 0, 0, 0);
        guiTransform2.setParent(cvBackground.getTransform());
        GuiTransform guiTransform3 = new GuiTransform(GuiAlign.BOTTOM_CENTER, 0, -24, 0, 0, 0);
        guiTransform3.setParent(cvBackground.getTransform());
        PanelLine paLine0 = new PanelLine(guiTransform2, guiTransform3, PresetLine.GUI_DIVIDER.getLine(), 1, PresetColor.GUI_DIVIDER.getColor(), 1);
        cvBackground.addPanel(paLine0);
        refreshQuestList();
    }

    public void onPanelEvent(PanelEvent event) {
        if (event instanceof PEventButton) {
            onButtonPress((PEventButton) event);
        }
    }

    private void onButtonPress(PEventButton event) {
        int y1;
        int s2;
        PanelButtonStorage button = event.getButton();
        if (button.getButtonID() == 0) {
            this.field_146297_k.func_147108_a(this.parent);
            return;
        }
        if (button.getButtonID() == 1) {
            this.field_146297_k.func_147108_a(new GuiQuest(this, ((DBEntry) button.getStoredValue()).getID()));
            return;
        }
        if (button.getButtonID() == 2) {
            DBEntry<IQuest> entry = (DBEntry) button.getStoredValue();
            QuestLineEntry questLineEntry = new QuestLineEntry(0, 0);
            int x1 = 0;
            int i = 0;
            loop0: while (true) {
                y1 = i;
                if (this.questLine == null) {
                    break;
                }
                for (DBEntry<IQuestLineEntry> qe2 : this.questLine.getEntries()) {
                    int x2 = ((IQuestLineEntry) qe2.getValue()).getPosX();
                    int y2 = ((IQuestLineEntry) qe2.getValue()).getPosY();
                    s2 = ((IQuestLineEntry) qe2.getValue()).getSize();
                    if (x1 < x2 || x1 >= x2 + s2 || y1 < y2 || y1 >= y2 + s2) {
                    }
                }
                break loop0;
                x1 += s2;
                i = y1 + s2;
            }
            questLineEntry.setPosition(x1, y1);
            this.questLine.add(entry.getID(), questLineEntry);
            SendChanges();
            return;
        }
        if (button.getButtonID() == 3 && this.questLine != null) {
            this.questLine.removeID(((DBEntry) button.getStoredValue()).getID());
            SendChanges();
            return;
        }
        if (button.getButtonID() == 4) {
            DBEntry<IQuest> entry2 = (DBEntry) button.getStoredValue();
            NBTTagCompound payload = new NBTTagCompound();
            payload.func_74783_a("questIDs", new int[]{entry2.getID()});
            payload.func_74768_a("action", 1);
            NetQuestEdit.sendEdit(payload);
            return;
        }
        if (button.getButtonID() != 5) {
            if (button.getButtonID() == 6) {
                NBTTagCompound payload2 = new NBTTagCompound();
                payload2.func_74783_a("questIDs", new int[]{((Integer) button.getStoredValue()).intValue()});
                payload2.func_74768_a("action", 1);
                NetQuestEdit.sendEdit(payload2);
                return;
            }
            return;
        }
        NBTTagCompound payload3 = new NBTTagCompound();
        NBTTagList dataList = new NBTTagList();
        NBTTagCompound entry3 = new NBTTagCompound();
        entry3.func_74768_a("questID", -1);
        dataList.func_74742_a(entry3);
        payload3.func_74782_a("data", dataList);
        payload3.func_74768_a("action", 3);
        NetQuestEdit.sendEdit(payload3);
    }

    private void refreshQuestList() {
        this.canvasQL.resetCanvas();
        if (this.questLine == null) {
            return;
        }
        int width = this.canvasQL.getTransform().getWidth();
        List<DBEntry<IQuestLineEntry>> qles = this.questLine.getEntries();
        for (int i = 0; i < qles.size(); i++) {
            DBEntry<IQuestLineEntry> entry = qles.get(i);
            IQuest quest = (IQuest) QuestDatabase.INSTANCE.getValue(entry.getID());
            if (quest == null) {
                PanelButtonStorage<Integer> btnErr = new PanelButtonStorage<>(new GuiRectangle(width - 16, i * 16, 16, 16, 0), 6, "[ERROR]", Integer.valueOf(entry.getID()));
                btnErr.setActive(true);
                this.canvasQL.addPanel(btnErr);
            } else {
                PanelButtonStorage<DBEntry<IQuest>> btnEdit = new PanelButtonStorage<>(new GuiRectangle(0, i * 16, width - 16, 16, 0), 1, QuestTranslation.translate((String) quest.getProperty(NativeProps.NAME), new Object[0]), new DBEntry(entry.getID(), quest));
                this.canvasQL.addPanel(btnEdit);
                PanelButtonStorage<DBEntry<IQuest>> btnRem = new PanelButtonStorage<>(new GuiRectangle(width - 16, i * 16, 16, 16, 0), 3, "", new DBEntry(entry.getID(), quest));
                btnRem.setIcon(PresetIcon.ICON_NEGATIVE.getTexture());
                this.canvasQL.addPanel(btnRem);
            }
        }
    }

    private void SendChanges() {
        if (this.questLine == null) {
            return;
        }
        NBTTagCompound payload = new NBTTagCompound();
        NBTTagList dataList = new NBTTagList();
        NBTTagCompound entry = new NBTTagCompound();
        entry.func_74768_a("chapterID", this.lineID);
        entry.func_74782_a("config", this.questLine.writeToNBT(new NBTTagCompound(), (List) null));
        dataList.func_74742_a(entry);
        payload.func_74782_a("data", dataList);
        payload.func_74768_a("action", 0);
        NetChapterEdit.sendEdit(payload);
    }
}
